#!/usr/bin/env node
/*!
 * gitmars v7.0.0-beta.18
 * 这是一个git工作流工具
 * (c) 2021-2024 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
import { program } from 'commander';
import sh from 'shelljs';
import chalk from 'chalk';
import { getConfig, getCurrentBranch } from '@gitmars/git';
import { spawnSync } from '@gitmars/utils';
import lang from './common/local.mjs';

const { t } = lang;
const { red } = chalk;
const config = getConfig();
program.name("gitm permission").usage("[message] [--no-verify] [--dev] [--release]").arguments("[message]").description(t("Verify commit permissions")).option("--no-verify", t("Do you want to skip the check permission"), false).option("--dev", t("Whether to restrict dev commits"), false).option("--release", t("Whether to restrict release commits"), false).action((message, opt) => {
  console.info("gitm permission is running");
  const current = getCurrentBranch();
  const allow = [config.master];
  const { stdout } = spawnSync("git", ["show"]);
  if (opt.dev)
    allow.push(config.develop);
  if (opt.release)
    allow.push(config.release);
  const index = allow.indexOf(current);
  if (index > -1 && !opt.noVerify && stdout && !stdout.includes("Merge:") && !stdout.includes("Merge branch")) {
    sh.echo(
      red(
        t("The {target} branch does not allow direct commits", {
          target: allow[index]
        })
      )
    );
    process.exit(1);
  } else {
    process.exit(0);
  }
});
program.parse(process.argv);
